==> zither-1.1.16.tar.gz: zither_prj/sitar/scan_port.c <==

#include<stdio.h>
#include<netinet/in.h>
#include<stdlib.h>
#include<string.h>
#include<time.h>
#include<unistd.h>

#include<pthread.h>
#include"sitar.h"
#include"sitar_scan.h"
#include<almemsys/almemsys.h>
#include"jpreturn.h"

/* 0 -> ch_stat       char*  open sccses = 0, not open sccses is !0 
   1 -> ch_prot       char*  for 'TCP,UDP,ICMP'
   2 -> ch_host       char*  127.0.0.1
   3 -> ch_port       char*  0~100000 Listn ports
        port          int
   4 -> ch_timeuot    char*  1 = 1sec
        timeout       int
   5 -> ch_info       char*  check cliants infolmationes

   needid file is 
   scan_udpport.c, scan_icmp.c, scan_tcpport.c
*/

/*
int scan_port(struct scan_buf *);
*/


/* ------ SCAN PORT --------- */
int scan_port(struct scan_buf *pd)
{
int ret = -1;
int inA = 0;
int inB = 0;
int out = 1;
char * info_swap;

info_swap = (char *)calloc(IP_LEN, sizeof(char));

if((self_memcmp(pd->ch_prot, "HOST")) == 0){
   pd->ch_info = scan_host(pd->ch_com, pd->ch_host, pd->ch_info, pd->timeout, &ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot, "SNTP")) == 0){
   pd->ch_info = scan_sntp_connect(123, pd->ch_host, pd->ch_info, pd->timeout, &ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot, "ICMP")) == 0){
   // 20071220 rip のタイムラグの問題を修正
   pd->ch_info=scan_icmp(pd->ch_host, pd->ch_info, pd->timeout, &ret, 10); // 1回め
   usleep(100000);
   pd->ch_info=scan_icmp(pd->ch_host, pd->ch_info, pd->timeout, &ret, 10); // 2回め
   usleep(100000);
   pd->ch_info=scan_icmp(pd->ch_host, pd->ch_info, pd->timeout, &ret, 10); // 3回め
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot,"URL")) == 0){
   pd->ch_info=scan_url_connect(pd->port, pd->ch_host, pd->ch_info, pd->timeout, &ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot,"SMTP")) == 0){
   pd->ch_info = scan_smtp_connect(pd->port,pd->ch_host,pd->ch_info,pd->timeout,&ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot,"DHW")) == 0){
   pd->ch_info = scan_dhw_connect(pd->ch_com, pd->port, pd->ch_host, pd->ch_info, pd->timeout,&ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot, "TCP")) == 0){
   pd->ch_info=scan_tcp_connect(pd->port, pd->ch_host, pd->ch_info, pd->timeout, &ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot, "UDP")) == 0){

   info_swap = scan_icmp(pd->ch_host, info_swap, pd->timeout, &inA, 10); // 1回め
   usleep(100000);
   info_swap = scan_icmp(pd->ch_host, info_swap, pd->timeout, &inA, 10); // 2回め
   usleep(100000);
   info_swap = scan_icmp(pd->ch_host, info_swap, pd->timeout, &inA, 10); // 3回め

   pd->ch_info = scan_udp_connect(pd->port, pd->ch_host, pd->ch_info, pd->timeout, &inB);

   if(inA == 0 && inB == 0){
      ret = 0;
      }

   else if(inA != 0 && inB == 0){
      ret = -3;
      #ifdef SCAN_PORT_DEBUG
      fprintf(stderr,"SCAN_PORT: scan_port(): %s non icmp support or not server\n", pd->ch_host);
      #endif
      pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX,
            "%s %s. ", pd->ch_host, info_swap);
      }

   else if(inA != 0 && inB != 0){
      ret = -2;
      #ifdef SCAN_PORT_DEBUG
      fprintf(stderr,"SCAN_PORT: scan_port(): %s is not server\n", pd->ch_host);
      #endif
      }

   else if(inA == 0 && inB != 0){
      ret = -1;
      #ifdef SCAN_PORT_DEBUG
      fprintf(stderr,"SCAN_PORT: scan_port(): %s is icmp support ok. bat <port=%d> is not open\n",
      pd->ch_host, pd->port);
      #endif
      }

   else{
      ret = -1;
      #ifdef SCAN_PORT_DEBUG
      fprintf(stderr,"SCAN_PORT: scan_port(): %s <port=%d> not support ???\n",
      pd->ch_host, pd->port);
      #endif
      }

   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else{
   ret = -1;
   pd->ch_info=safe_memcpy(pd->ch_info,"not support protocoll.\n",BUF_MAX);
   }



// テストとログモードの処理
if(0 == self_memcmp(pd->ch_plai, "4")){
   out = 4;
   #ifdef SCAN_PORT_DEBUG
   printf("SCAN_PORT: scan_port(): port chack out = %d\n", out);
   #endif
   if(2 > strlen(pd->ch_info)){
      pd->ch_info = safe_memcpy(pd->ch_info, COM_3, BUF_MAX );
      }
   ret = -1;
   }
else if(0 == self_memcmp(pd->ch_plai, "11")){
   if(2 > strlen(pd->ch_info)){
      pd->ch_info = safe_memcpy(pd->ch_info, COM_4, BUF_MAX );
      }
   #ifdef SCAN_PORT_DEBUG
   printf("SCAN_PORT: scan_port(): plai = %s ret = %d\n", pd->ch_plai, ret);
   #endif
   if(ret == -1){
      pd->ch_plai = safe_memcpy(pd->ch_plai, "1", BUF_MAX);
      }
   ret = -1;
   }
else if(0 == self_memcmp(pd->ch_plai, "12")){
   if(2 > strlen(pd->ch_info)){
      pd->ch_info = safe_memcpy(pd->ch_info, COM_4, BUF_MAX );
      }
   #ifdef SCAN_PORT_DEBUG
   printf("SCAN_PORT: scan_port(): plai = %s ret = %d\n", pd->ch_plai, ret);
   #endif
   if(ret == -1){
      pd->ch_plai = safe_memcpy(pd->ch_plai, "2", BUF_MAX);
      }
   ret = -1;
   }
else if(0 == self_memcmp(pd->ch_plai, "13")){
   if(2 > strlen(pd->ch_info)){
      pd->ch_info = safe_memcpy(pd->ch_info, COM_4, BUF_MAX );
      }
   #ifdef SCAN_PORT_DEBUG
   printf("SCAN_PORT: scan_port(): plai = %s ret = %d\n", pd->ch_plai, ret);
   #endif
   if(ret == -1){
      pd->ch_plai = safe_memcpy(pd->ch_plai, "3", BUF_MAX);
      }
   ret = -1;
   }


// if(out == 4){
//    if(2 > strlen(pd->ch_info)){
//       pd->ch_info = safe_memcpy(pd->ch_info, COM_3, BUF_MAX );
//       }
//    ret = -1;
//    }

/* */

// check_statの設定 正か逆かで反転する。
// 監視の正逆の判断 check_stat == 1 はエラー 0は正常
if(ret < 0){

   if(pd->ch_stat[0] == '0'){
      pd->check_stat = 1;
      }
   else if(pd->ch_stat[0] == '1'){
      pd->check_stat = 0;
      }
   }

if(ret >= 0){

   if(pd->ch_stat[0] == '1'){
      pd->check_stat = 1;
      }
   else if(pd->ch_stat[0] == '0'){
      pd->check_stat = 0;
      }
   }


free(info_swap);

return 0;
}

==> zither-1.1.18.tar.gz: zither_prj/sitar/scan_port.c <==

#include<stdio.h>
#include<netinet/in.h>
#include<stdlib.h>
#include<string.h>
#include<time.h>
#include<unistd.h>

#include<pthread.h>
#include"sitar.h"
#include"sitar_scan.h"
#include<almemsys/almemsys.h>
#include"jpreturn.h"


/* ------ SCAN PORT --------- */
int scan_port(struct scan_buf *pd)
{
int st;
int ret = -1;
int inA = 0;
int inB = 0;
int out = 1;
int by = 100; // ICMPのしきい値が1の場合、10msec (0.1秒)

st = 0;

if((self_memcmp(pd->ch_prot, "HOST")) == 0){
   pd->ch_info = scan_host(pd->ch_com, pd->ch_host, pd->ch_info, pd->timeout, &ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot, "SNTP")) == 0){
   pd->ch_info = scan_sntp_connect(123, pd->ch_host, pd->ch_info, pd->timeout, &ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot, "ICMP")) == 0){

   pd->ch_info=scan_icmp(pd->ch_host, pd->ch_info, pd->timeout, &ret, by); // 1回め
   usleep(1000000);
   pd->ch_info=scan_icmp(pd->ch_host, pd->ch_info, pd->timeout, &ret, by); // 2回め

   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot,"URL")) == 0){
   pd->ch_info=scan_url_connect(pd->port, pd->ch_host, pd->ch_info, pd->timeout, &ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot,"SSL")) == 0){
   //  1209600 = 2週間の秒　証明証が安全に更新出来る時間
   time_t lim;
   if(0 <= ch_int2(pd->ch_com)){
      lim = (86400 * strtol(pd->ch_com, (char **)NULL, 10));
      }
   else{
      lim = 1209600;
      }
   #ifdef SSL_BUG
   printf("SSL_BUG: scan_ssl_connect(x509): limit time = %ld\n", lim);
   #endif

   pd->ch_info=scan_ssl_command(pd->port, pd->ch_host, pd->ch_info, pd->timeout, lim, &ret, pd->ch_plai);

   if(0 == (int)strlen(pd->ch_info)){
      if(ret > -1){
         pd->ch_info=safe_sprintf(pd->ch_info, BUF_MAX,"port=%d host_data=%s: %s\n", pd->port, pd->ch_host, HTTPS_1);
         }
      else{
         pd->ch_info=safe_sprintf(pd->ch_info, BUF_MAX,"port=%d host_data=%s: %s\n", pd->port, pd->ch_host, HTTPS_2);
         }
      }
   #ifdef SSL_BUG
   printf("SSL_BUG: scan_ssl_connect(): %d, %s, <%s>, %d, %d, %d, %s\n"
     ,pd->port, pd->ch_host, pd->ch_info, pd->timeout, lim, ret, pd->ch_plai);
   #endif
   }

else if((self_memcmp(pd->ch_prot,"SMTP")) == 0){
   pd->ch_info = scan_smtp_connect(pd->port, pd->ch_host, pd->ch_info,pd->timeout,&ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot,"DHW")) == 0){
   pd->ch_info = scan_dhw_connect(pd->ch_com, pd->port, pd->ch_host, pd->ch_info, pd->timeout,&ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot, "TCP")) == 0){
   pd->ch_info=scan_tcp_connect(pd->port, pd->ch_host, pd->ch_info, pd->timeout, &ret);
   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else if((self_memcmp(pd->ch_prot, "UDP")) == 0){

// info_swap = scan_icmp(pd->ch_host, info_swap, pd->timeout, &inA, by); // 1回め
   pd->ch_info = scan_icmp(pd->ch_host, pd->ch_info, pd->timeout, &inA, by); // 1回め
   usleep(1000000);
// info_swap = scan_icmp(pd->ch_host, info_swap, pd->timeout, &inA, by); // 2回め
   pd->ch_info = scan_icmp(pd->ch_host, pd->ch_info, pd->timeout, &inA, by); // 2回め

   pd->ch_info = scan_udp_connect(pd->port, pd->ch_host, pd->ch_info, pd->timeout, &inB);

   if(inA == 0 && inB == 0){
      ret = 0;
      }

   else if(inA != 0 && inB == 0){
      ret = -3;
      #ifdef SCAN_PORT_DEBUG
      fprintf(stderr,"SCAN_PORT: scan_port(): %s non icmp support or not server\n", pd->ch_host);
      #endif
//    pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX, "%s %s. ", pd->ch_host, info_swap);
      pd->ch_info = safe_sprintf(pd->ch_info, BUF_MAX, "%s %s. ", pd->ch_host, "non icmp suppot or not server.");
      }

   else if(inA != 0 && inB != 0){
      ret = -2;
      #ifdef SCAN_PORT_DEBUG
      fprintf(stderr,"SCAN_PORT: scan_port(): %s is not server\n", pd->ch_host);
      #endif
      }

   else if(inA == 0 && inB != 0){
      ret = -1;
      #ifdef SCAN_PORT_DEBUG
      fprintf(stderr,"SCAN_PORT: scan_port(): %s is icmp support ok. bat <port=%d> is not open\n",
      pd->ch_host, pd->port);
      #endif
      }

   else{
      ret = -1;
      #ifdef SCAN_PORT_DEBUG
      fprintf(stderr,"SCAN_PORT: scan_port(): %s <port=%d> not support ???\n",
      pd->ch_host, pd->port);
      #endif
      }

   if(0 == (int)strlen(pd->ch_info)){
      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
      }
   }

else{
   ret = -1;
   pd->ch_info=safe_memcpy(pd->ch_info,"not support protocoll.\n",BUF_MAX);
   }



// テストとログモードの処理
if(0 == self_memcmp(pd->ch_plai, "4")){
   out = 4;
   #ifdef SCAN_PORT_DEBUG
   printf("SCAN_PORT: scan_port(): port chack out = %d\n", out);
   #endif
   if(2 > strlen(pd->ch_info)){
      pd->ch_info = safe_memcpy(pd->ch_info, COM_3, BUF_MAX );
      }
   ret = -1;
   }
else if(0 == self_memcmp(pd->ch_plai, "11")){
   if(2 > strlen(pd->ch_info)){
      pd->ch_info = safe_memcpy(pd->ch_info, COM_4, BUF_MAX );
      }
   #ifdef SCAN_PORT_DEBUG
   printf("SCAN_PORT: scan_port(): plai = %s ret = %d\n", pd->ch_plai, ret);
   #endif
   if(ret == -1){
      pd->ch_plai = safe_memcpy(pd->ch_plai, "1", BUF_MAX);
      }
   ret = -1;
   }
else if(0 == self_memcmp(pd->ch_plai, "12")){
   if(2 > strlen(pd->ch_info)){
      pd->ch_info = safe_memcpy(pd->ch_info, COM_4, BUF_MAX );
      }
   #ifdef SCAN_PORT_DEBUG
   printf("SCAN_PORT: scan_port(): plai = %s ret = %d\n", pd->ch_plai, ret);
   #endif
   if(ret == -1){
      pd->ch_plai = safe_memcpy(pd->ch_plai, "2", BUF_MAX);
      }
   ret = -1;
   }
else if(0 == self_memcmp(pd->ch_plai, "13")){
   if(2 > strlen(pd->ch_info)){
      pd->ch_info = safe_memcpy(pd->ch_info, COM_4, BUF_MAX );
      }
   #ifdef SCAN_PORT_DEBUG
   printf("SCAN_PORT: scan_port(): plai = %s ret = %d\n", pd->ch_plai, ret);
   #endif
   if(ret == -1){
      pd->ch_plai = safe_memcpy(pd->ch_plai, "3", BUF_MAX);
      }
   ret = -1;
   }

// check_statの設定 正か逆かで反転する。
// 監視の正逆の判断 check_stat == 1 はエラー 0は正常
if(ret < 0){

   if(pd->ch_stat[0] == '0'){
      pd->check_stat = 1;
      }
   else if(pd->ch_stat[0] == '1'){
      pd->check_stat = 0;
      }
   }

if(ret >= 0){

   if(pd->ch_stat[0] == '1'){
      pd->check_stat = 1;
      }
   else if(pd->ch_stat[0] == '0'){
      pd->check_stat = 0;
      }
   }

return 0;
}
